==> base-domain-RD1000957-20190605.070101-1-sources.jar: com/thebeastshop/scm/vo/EditProductSkuInfoVo.java <==
package com.thebeastshop.scm.vo;

import pers.richard.ormybatis.domain.core.AbstractDomain;

import java.math.BigDecimal;

/**
 * prod编辑页面的SKU vo
 */
public class EditProductSkuInfoVo extends AbstractDomain {

	private String name;
	private String nameCn;
	private String code;
	private String skuCategoryName;
	private Integer minAmount;
	private Integer brandId;
	private String brandName;
	private String brandNameCN;
	private BigDecimal salesPrice ;
	private String bu;
	
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getNameCn() {
		return nameCn;
	}
	public void setNameCn(String nameCn) {
		this.nameCn = nameCn;
	}
	public String getCode() {
		return code;
	}
	public void setCode(String code) {
		this.code = code;
	}
	public String getSkuCategoryName() {
		return skuCategoryName;
	}
	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}
	public Integer getMinAmount() {
		return minAmount;
	}
	public void setMinAmount(Integer minAmount) {
		this.minAmount = minAmount;
	}

	public Integer getBrandId() {
		return brandId;
	}

	public void setBrandId(Integer brandId) {
		this.brandId = brandId;
	}

	public String getBrandName() {
		return brandName;
	}

	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}

	public String getBrandNameCN() {
		return brandNameCN;
	}

	public void setBrandNameCN(String brandNameCN) {
		this.brandNameCN = brandNameCN;
	}

	public BigDecimal getSalesPrice() {
		return salesPrice;
	}

	public void setSalesPrice(BigDecimal salesPrice) {
		this.salesPrice = salesPrice;
	}

	public String getBu() {
		return bu;
	}

	public void setBu(String bu) {
		this.bu = bu;
	}
}

==> base-domain-RD1002407-20200214.134246-3-sources.jar: com/thebeastshop/scm/vo/EditProductSkuInfoVo.java <==
package com.thebeastshop.scm.vo;

import pers.richard.ormybatis.domain.core.AbstractDomain;

import java.math.BigDecimal;

/**
 * prod编辑页面的SKU vo
 */
public class EditProductSkuInfoVo extends AbstractDomain {

	private String name;
	private String nameCn;
	private String code;
	private String skuCategoryName;
	private Integer minAmount;
	private Integer brandId;
	private String brandName;
	private String brandNameCN;
	private BigDecimal salesPrice ;
	private String bu;
	private String skuImg;

	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getNameCn() {
		return nameCn;
	}
	public void setNameCn(String nameCn) {
		this.nameCn = nameCn;
	}
	public String getCode() {
		return code;
	}
	public void setCode(String code) {
		this.code = code;
	}
	public String getSkuCategoryName() {
		return skuCategoryName;
	}
	public void setSkuCategoryName(String skuCategoryName) {
		this.skuCategoryName = skuCategoryName;
	}
	public Integer getMinAmount() {
		return minAmount;
	}
	public void setMinAmount(Integer minAmount) {
		this.minAmount = minAmount;
	}

	public Integer getBrandId() {
		return brandId;
	}

	public void setBrandId(Integer brandId) {
		this.brandId = brandId;
	}

	public String getBrandName() {
		return brandName;
	}

	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}

	public String getBrandNameCN() {
		return brandNameCN;
	}

	public void setBrandNameCN(String brandNameCN) {
		this.brandNameCN = brandNameCN;
	}

	public BigDecimal getSalesPrice() {
		return salesPrice;
	}

	public void setSalesPrice(BigDecimal salesPrice) {
		this.salesPrice = salesPrice;
	}

	public String getBu() {
		return bu;
	}

	public void setBu(String bu) {
		this.bu = bu;
	}

	public String getSkuImg() {
		return skuImg;
	}

	public void setSkuImg(String skuImg) {
		this.skuImg = skuImg;
	}

}
